@@ -32,20 +32,16 @@
 #include "stemming.h"
 
 
-#include <kglobal.h>
+#include <klocalizedstring.h>
 #include <kmessagebox.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kurl.h>
-
-#include <kprogressdialog.h>
-
 #include <kreplacedialog.h>
 #include <kreplace.h>
+#include <kdemacros.h>
 
 #include <sonnet/backgroundchecker.h>
 #include <sonnet/dialog.h>
 
+#include <QDebug>
 #include <QTimer>
 #include <QPointer>
 
@@ -179,52 +175,8 @@ static void calcOffsetWithAccels(const QString& data, int& offset, int& length)
             limit=qMin(data.size(),offset+length);//just safety
         }
 }
-
-void EditorTab::find()
-{
-    //QWidget* p=0; QWidget* next=qobject_cast<QWidget*>(parent()); while(next) { p=next; next=qobject_cast<QWidget*>(next->parent()); }
-    EntryFindDialog::instance(nativeParentWidget());
-
-    QString sel=selectionInTarget();
-    if (!(sel.isEmpty()&&selectionInSource().isEmpty()))
-    {
-        if (sel.isEmpty())
-            sel=selectionInSource();
-        if (_find&&_find->options()&IGNOREACCELS)
-            sel.remove('&');
-            EntryFindDialog::instance()->setPattern(sel);
-    }
-
-    if ( EntryFindDialog::instance()->exec() != QDialog::Accepted )
-        return;
-
-    if (_find)
-    {
-        _find->resetCounts();
-        _find->setPattern(EntryFindDialog::instance()->pattern());
-        _find->setOptions(EntryFindDialog::instance()->options());
-
-    }
-    else // This creates a find-next-prompt dialog if needed.
-    {
-        _find = new KFind(EntryFindDialog::instance()->pattern(),EntryFindDialog::instance()->options(),this,EntryFindDialog::instance());
-        connect(_find,SIGNAL(highlight(QString,int,int)),this, SLOT(highlightFound(QString,int,int)) );
-        connect(_find,SIGNAL(findNext()),this,SLOT(findNext()));
-        _find->closeFindNextDialog();
-    }
-
-    DocPosition pos;
-    if (_find->options() & KFind::FromCursor)
-        pos=m_currentPos;
-    else if (!determineStartingPos(_find,pos))
-            return;
-
-
-    findNext(pos);
-}
-
-bool EditorTab::determineStartingPos(KFind* find,
-                                  DocPosition& pos)
+static bool determineStartingPos(Catalog* m_catalog, KFind* find, DocPosition& pos) //search or replace
+                                                                //called from find() and findNext()
 {
     if (find->options() & KFind::FindBackwards)
     {
@@ -240,10 +192,53 @@ bool EditorTab::determineStartingPos(KFind* find,
     return true;
 }
 
+void EditorTab::find()
+{
+    //QWidget* p=0; QWidget* next=qobject_cast<QWidget*>(parent()); while(next) { p=next; next=qobject_cast<QWidget*>(next->parent()); }
+    EntryFindDialog::instance(nativeParentWidget());
+
+    QString sel=selectionInTarget();
+    if (!(sel.isEmpty()&&selectionInSource().isEmpty()))
+    {
+        if (sel.isEmpty())
+            sel=selectionInSource();
+        if (m_find&&m_find->options()&IGNOREACCELS)
+            sel.remove('&');
+            EntryFindDialog::instance()->setPattern(sel);
+    }
+
+    if ( EntryFindDialog::instance()->exec() != QDialog::Accepted )
+        return;
+
+    if (m_find)
+    {
+        m_find->resetCounts();
+        m_find->setPattern(EntryFindDialog::instance()->pattern());
+        m_find->setOptions(EntryFindDialog::instance()->options());
+
+    }
+    else // This creates a find-next-prompt dialog if needed.
+    {
+        m_find = new KFind(EntryFindDialog::instance()->pattern(),EntryFindDialog::instance()->options(),this,EntryFindDialog::instance());
+        connect(m_find,SIGNAL(highlight(QString,int,int)),this, SLOT(highlightFound(QString,int,int)) );
+        connect(m_find,SIGNAL(findNext()),this,SLOT(findNext()));
+        m_find->closeFindNextDialog();
+    }
+
+    DocPosition pos;
+    if (m_find->options() & KFind::FromCursor)
+        pos=m_currentPos;
+    else if (!determineStartingPos(m_catalog, m_find, pos))
+            return;
+
+
+    findNext(pos);
+}
+
 void EditorTab::findNext(const DocPosition& startingPos)
 {
     Catalog& catalog=*m_catalog;
-    KFind& find=*_find;
+    KFind& find=*m_find;
 
     if (KDE_ISUNLIKELY( catalog.numberOfEntries()<=startingPos.entry ))
         return;//for the case when app wasn't able to process event before file close
@@ -258,8 +253,8 @@ void EditorTab::findNext(const DocPosition& startingPos)
     QRegExp rx("[^(\\\\n)>]\n");
     QTime a;a.start();
     //_searchingPos.part=DocPosition::Source;
-    bool ignoreaccels=_find->options()&IGNOREACCELS;
-    bool includenotes=_find->options()&INCLUDENOTES;
+    bool ignoreaccels=m_find->options()&IGNOREACCELS;
+    bool includenotes=m_find->options()&INCLUDENOTES;
     int switchOptions=DocPosition::Source|DocPosition::Target|(includenotes*DocPosition::Comment);
     int flag=1;
     while (flag)
@@ -304,7 +299,7 @@ void EditorTab::findNext(const DocPosition& startingPos)
             if(find.shouldRestart(true,true))
             {
                 flag=1;
-                determineStartingPos(_find,_searchingPos);
+                determineStartingPos(m_catalog, m_find,_searchingPos);
             }
             find.resetCounts();
         }
@@ -313,7 +308,7 @@ void EditorTab::findNext(const DocPosition& startingPos)
 
 void EditorTab::findNext()
 {
-    if (_find)
+    if (m_find)
     {
         findNext((m_currentPos.entry==_searchingPos.entry&&_searchingPos.part==DocPosition::Comment)?
                         _searchingPos:m_currentPos);
@@ -326,9 +321,9 @@ void EditorTab::findNext()
 void EditorTab::findPrev()
 {
 
-    if (_find)
+    if (m_find)
     {
-        _find->setOptions(_find->options() ^ KFind::FindBackwards);
+        m_find->setOptions(m_find->options() ^ KFind::FindBackwards);
         findNext(m_currentPos);
     }
     else
@@ -340,7 +335,7 @@ void EditorTab::findPrev()
 
 void EditorTab::highlightFound(const QString &,int matchingIndex,int matchedLength)
 {
-    if (_find->options()&IGNOREACCELS && _searchingPos.part!=DocPosition::Comment)
+    if (m_find->options()&IGNOREACCELS && _searchingPos.part!=DocPosition::Comment)
     {
         QString data=m_catalog->catalogString(_searchingPos).string;
         calcOffsetWithAccels(data, matchingIndex, matchedLength);
@@ -356,7 +351,7 @@ void EditorTab::replace()
 
     if (!m_view->selectionInTarget().isEmpty())
     {
-        if (_replace&&_replace->options()&IGNOREACCELS)
+        if (m_replace&&m_replace->options()&IGNOREACCELS)
         {
             QString tmp(m_view->selectionInTarget());
             tmp.remove('&');
@@ -371,15 +366,15 @@ void EditorTab::replace()
         return;
 
 
-    if (_replace) _replace->deleteLater();// _replace=0;
+    if (m_replace) m_replace->deleteLater();// _replace=0;
 
     // This creates a find-next-prompt dialog if needed.
     {
-        _replace = new KReplace(EntryReplaceDialog::instance()->pattern(),EntryReplaceDialog::instance()->replacement(),EntryReplaceDialog::instance()->options(),this,EntryReplaceDialog::instance());
-        connect(_replace,SIGNAL(highlight(QString,int,int)),    this,SLOT(highlightFound_(QString,int,int)));
-        connect(_replace,SIGNAL(findNext()),                    this,SLOT(replaceNext()));
-        connect(_replace,SIGNAL(replace(QString,int,int,int)),  this,SLOT(doReplace(QString,int,int,int)));
-        connect(_replace,SIGNAL(dialogClosed()),                this,SLOT(cleanupReplace()));
+        m_replace = new KReplace(EntryReplaceDialog::instance()->pattern(),EntryReplaceDialog::instance()->replacement(),EntryReplaceDialog::instance()->options(),this,EntryReplaceDialog::instance());
+        connect(m_replace,SIGNAL(highlight(QString,int,int)),    this,SLOT(highlightFound_(QString,int,int)));
+        connect(m_replace,SIGNAL(findNext()),                    this,SLOT(replaceNext()));
+        connect(m_replace,SIGNAL(replace(QString,int,int,int)),  this,SLOT(doReplace(QString,int,int,int)));
+        connect(m_replace,SIGNAL(dialogClosed()),                this,SLOT(cleanupReplace()));
 //         _replace->closeReplaceNextDialog();
     }
 //     else
@@ -392,12 +387,12 @@ void EditorTab::replace()
     //m_catalog->beginMacro(i18nc("@item Undo action item","Replace"));
     m_doReplaceCalled=false;
 
-    if (_replace->options() & KFind::FromCursor)
+    if (m_replace->options() & KFind::FromCursor)
         replaceNext(m_currentPos);
     else
     {
         DocPosition pos;
-        if (!determineStartingPos(_replace,pos)) return;
+        if (!determineStartingPos(m_catalog, m_replace,pos)) return;
         replaceNext(pos);
     }
 
@@ -406,7 +401,7 @@ void EditorTab::replace()
 
 void EditorTab::replaceNext(const DocPosition& startingPos)
 {
-    bool anotherEntry=_replacingPos.entry!=_replacingPos.entry;
+    bool anotherEntry=m_currentPos.entry!=_replacingPos.entry;
     _replacingPos=startingPos;
 
     if (anotherEntry)
@@ -414,9 +409,9 @@ void EditorTab::replaceNext(const DocPosition& startingPos)
 
 
     int flag=1;
-    bool ignoreaccels=_replace->options()&IGNOREACCELS;
-    bool includenotes=_replace->options()&INCLUDENOTES;
-    kWarning()<<"includenotes"<<includenotes;
+    bool ignoreaccels=m_replace->options()&IGNOREACCELS;
+    bool includenotes=m_replace->options()&INCLUDENOTES;
+    qWarning()<<"includenotes"<<includenotes;
     int switchOptions=DocPosition::Target|(includenotes*DocPosition::Comment);
     while (flag)
     {
@@ -424,7 +419,7 @@ void EditorTab::replaceNext(const DocPosition& startingPos)
         KFind::Result res=KFind::NoMatch;
         while (1)
         {
-            if (_replace->needData()||anotherEntry/*||m_view->m_modifiedAfterFind*/)
+            if (m_replace->needData()||anotherEntry/*||m_view->m_modifiedAfterFind*/)
             {
                 anotherEntry=false;
                 //m_view->m_modifiedAfterFind=false;//NOTE TEST THIS
@@ -437,14 +432,14 @@ void EditorTab::replaceNext(const DocPosition& startingPos)
                     data=m_catalog->targetWithTags(_replacingPos).string;
                     if (ignoreaccels) data.remove('&');
                 }
-                _replace->setData(data);
+                m_replace->setData(data);
             }
-            res = _replace->replace();
+            res = m_replace->replace();
             if (res!=KFind::NoMatch)
                 break;
 
             if (!(
-                  (_replace->options()&KFind::FindBackwards)?
+                  (m_replace->options()&KFind::FindBackwards)?
                                 switchPrev(m_catalog,_replacingPos,switchOptions):
                                 switchNext(m_catalog,_replacingPos,switchOptions)
                  ))
@@ -453,21 +448,21 @@ void EditorTab::replaceNext(const DocPosition& startingPos)
 
         if (res==KFind::NoMatch)
         {
-            if((_replace->options()&KFind::FromCursor)
-                &&_replace->shouldRestart(true))
+            if((m_replace->options()&KFind::FromCursor)
+                &&m_replace->shouldRestart(true))
             {
                 flag=1;
-                determineStartingPos(_replace,_replacingPos);
+                determineStartingPos(m_catalog, m_replace,_replacingPos);
             }
             else
             {
-                if(!(_replace->options() & KFind::FromCursor))
-                     _replace->displayFinalDialog();
+                if(!(m_replace->options() & KFind::FromCursor))
+                     m_replace->displayFinalDialog();
 
-                _replace->closeReplaceNextDialog();
+                m_replace->closeReplaceNextDialog();
                 cleanupReplace();
             }
-            _replace->resetCounts();
+            m_replace->resetCounts();
         }
     }
 }
@@ -488,7 +483,7 @@ void EditorTab::replaceNext()
 
 void EditorTab::highlightFound_(const QString &,int matchingIndex,int matchedLength)
 {
-    if (_replace->options()&IGNOREACCELS)
+    if (m_replace->options()&IGNOREACCELS)
     {
         QString data=m_catalog->targetWithTags(_replacingPos).string;
         calcOffsetWithAccels(data,matchingIndex,matchedLength);
@@ -513,7 +508,7 @@ void EditorTab::doReplace(const QString &newStr,int offset,int newLen,int remLen
     {
         QString oldStr=m_catalog->target(_replacingPos);
 
-        if (_replace->options()&IGNOREACCELS)
+        if (m_replace->options()&IGNOREACCELS)
             calcOffsetWithAccels(oldStr,offset,remLen);
 
         pos.offset=offset;
@@ -568,9 +563,9 @@ void EditorTab::spellcheck()
 
     _spellcheckPos=m_currentPos;
     _spellcheckStartPos=m_currentPos;
-    _spellcheckStop=false;
+    m_spellcheckStop=false;
     //m_catalog->beginMacro(i18n("Spellcheck"));
-    _spellcheckStartUndoIndex=m_catalog->index();
+    m_spellcheckStartUndoIndex=m_catalog->index();
     m_sonnetDialog->show();
 
 }
@@ -578,15 +573,15 @@ void EditorTab::spellcheck()
 
 void EditorTab::spellcheckNext()
 {
-    if (_spellcheckStop)
+    if (m_spellcheckStop)
         return;
 
     do
     {
         if (!switchNext(m_catalog,_spellcheckPos))
         {
-            kWarning()<<_spellcheckStartPos.entry;
-            kWarning()<<_spellcheckStartPos.form;
+            qWarning()<<_spellcheckStartPos.entry;
+            qWarning()<<_spellcheckStartPos.form;
             bool continueFromStart=
                 !(_spellcheckStartPos.entry==0 && _spellcheckStartPos.form==0)
                 && KMessageBox::questionYesNo(this,i18n("Lokalize has reached end of document. Do you want to continue from start?"), i18nc("@title", "Spellcheck"))==KMessageBox::Yes;
@@ -612,12 +607,12 @@ void EditorTab::spellcheckNext()
 
 void EditorTab::spellcheckStop()
 {
-    _spellcheckStop=true;
+    m_spellcheckStop=true;
 }
 
 void EditorTab::spellcheckCancel()
 {
-    m_catalog->setIndex(_spellcheckStartUndoIndex);
+    m_catalog->setIndex(m_spellcheckStartUndoIndex);
     gotoEntry(_spellcheckPos);
 }
 
@@ -663,53 +658,3 @@ void EditorTab::spellcheckReplace(QString oldWord, int offset, const QString &ne
 
 
 
-
-
-
-
-
-
-bool EditorTab::findEntryBySourceContext(const QString& source, const QString& ctxt)
-{
-    DocPosition pos(0);
-    do
-    {
-        if (m_catalog->source(pos)==source && m_catalog->context(pos.entry)==QStringList(ctxt))
-        {
-            gotoEntry(pos);
-            return true;
-        }
-    }
-    while (switchNext(m_catalog,pos));
-    return false;
-}
-
-
-void EditorTab::displayWordCount()
-{
-    //TODO in trans and fuzzy separately
-    int sourceCount=0;
-    int targetCount=0;
-    QRegExp rxClean(Project::instance()->markup()+'|'+Project::instance()->accel());//cleaning regexp; NOTE isEmpty()?
-    QRegExp rxSplit("\\W|\\d");//splitting regexp
-    DocPosition pos(0);
-    do
-    {
-        QString msg=m_catalog->source(pos);
-        msg.remove(rxClean);
-        QStringList words=msg.split(rxSplit,QString::SkipEmptyParts);
-        sourceCount+=words.size();
-
-        msg=m_catalog->target(pos);
-        msg.remove(rxClean);
-        words=msg.split(rxSplit,QString::SkipEmptyParts);
-        targetCount+=words.size();
-    }
-    while (switchNext(m_catalog,pos));
-
-    KMessageBox::information(this, i18nc("@info words count",
-                            "Source text words: %1<br/>Target text words: %2",
-                                        sourceCount,targetCount),i18nc("@title","Word Count"));
-}
-
-
